@@ -1,36 +1,36 @@
 context("as_sp")
 
 test_that("as_sp converts search results to SpatialPointsDF", {
-    oakland_public_sp <- as_sp(oakland_public)
+    oakland_public_sp <- expect_warning(as_sp(oakland_public))
     expect_is(oakland_public_sp, "SpatialPointsDataFrame")
 })
 
 test_that("as_sp converts isochrone results to SpatialLines/PolygonsDF", {
-    marina_walks_sp <- as_sp(marina_walks)
+    marina_walks_sp <- expect_warning(as_sp(marina_walks))
     # would by SpatialPolygons if used polygons = TRUE in the mz_isochrone call
     expect_is(marina_walks_sp, "SpatialLinesDataFrame")
 
-    marina_walks_polygons_sp <- as_sp(marina_walks_polygons)
+    marina_walks_polygons_sp <- expect_warning(as_sp(marina_walks_polygons))
     expect_is(marina_walks_polygons_sp, "SpatialPolygonsDataFrame")
 })
 
 test_that("as_sp converts vector tile layers to the appropriate Spatial*DF", {
-    roadlines <- as_sp(ca_tiles$roads, geometry_type = "line")
+    roadlines <- expect_warning(as_sp(ca_tiles$roads, geometry_type = "line"))
     expect_is(roadlines, "SpatialLinesDataFrame")
 
-    earthpolygons <- as_sp(ca_tiles$earth, geometry_type = "polygon")
+    earthpolygons <- expect_warning(as_sp(ca_tiles$earth, geometry_type = "polygon"))
     expect_is(earthpolygons, "SpatialPolygonsDataFrame")
 
-    waterpoints <- as_sp(ca_tiles$water, geometry_type = "point")
+    waterpoints <- expect_warning(as_sp(ca_tiles$water, geometry_type = "point"))
     expect_is(waterpoints, "SpatialPointsDataFrame")
 })
 
 test_that("as_sp errors on empty search results", {
     empty_search <- oakland_public
     empty_search$features <- list()
-    expect_error(as_sp(empty_search), "no data")
+    expect_error(expect_warning(as_sp(empty_search)), "no data")
 })
 
 test_that("as_sp errors on emtpy vector tile layers", {
-    expect_error(as_sp(ca_tiles$buildings), "empty")
+    expect_error(expect_warning(as_sp(ca_tiles$buildings)), "empty")
 })
